.. _core-dataflow-api:

Data flow
=========

.. automodule:: tidyms2.core.dataflow
   :members:
        BaseProcessStatus,
        SampleProcessStatus,
        AssayProcessStatus,
        MatrixProcessStatus
   :show-inheritance:
   :inherited-members: BaseModel
   :exclude-members: model_computed_fields, model_config, model_fields